# coding: utf-8

"""
    videoapi

    The video APIs help you convert, encode, and transcode videos.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from cloudmersive_video_api_client.api_client import ApiClient


class VideoApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def video_convert_to_gif(self, input_file, **kwargs):  # noqa: E501
        """Convert Video to Animated GIF format.  # noqa: E501

        Automatically detect video file format and convert it to animated GIF format. Supports many input video formats, including AVI, ASF, FLV, MP4, MPEG/MPG, Matroska/WEBM, 3G2, OGV, MKV, M4V and MOV. Uses 1 API call per 10 MB of file size. Maximum output file size is 50GB. Default height is 250 pixels, while preserving the video's aspect ratio.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.video_convert_to_gif(input_file, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param file input_file: Input file to perform the operation on. (required)
        :param str file_url: Optional; URL of a video file being used for conversion. Use this option for files larger than 2GB.
        :param int max_width: Optional; Maximum width of the output video, up to the original video width. Defaults to 250 pixels.
        :param int max_height: Optional; Maximum height of the output video, up to the original video width. Defaults to 250 pixels.
        :param bool preserve_aspect_ratio: Optional; If false, the original video's aspect ratio will not be preserved, allowing customization of the aspect ratio using maxWidth and maxHeight, potentially skewing the video. Default is true.
        :param int frame_rate: Optional; Specify the frame rate of the output video. Defaults to 24 frames per second.
        :param bool extend_processing_time: Optional; If true, will allow additional processing time for the video file conversion, using one API call per additional minute over the 5 minute default processing time, up to a maximum of 25 total minutes. This is generally necessary for files larger than 500 MB or longer than 30 minutes.
        :param datetime start_time: Optional; Specify the desired starting time of the GIF video in TimeSpan format.
        :param datetime time_span: Optional; Specify the desired length of the GIF video in TimeSpan format. Limit is 30 minutes.
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.video_convert_to_gif_with_http_info(input_file, **kwargs)  # noqa: E501
        else:
            (data) = self.video_convert_to_gif_with_http_info(input_file, **kwargs)  # noqa: E501
            return data

    def video_convert_to_gif_with_http_info(self, input_file, **kwargs):  # noqa: E501
        """Convert Video to Animated GIF format.  # noqa: E501

        Automatically detect video file format and convert it to animated GIF format. Supports many input video formats, including AVI, ASF, FLV, MP4, MPEG/MPG, Matroska/WEBM, 3G2, OGV, MKV, M4V and MOV. Uses 1 API call per 10 MB of file size. Maximum output file size is 50GB. Default height is 250 pixels, while preserving the video's aspect ratio.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.video_convert_to_gif_with_http_info(input_file, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param file input_file: Input file to perform the operation on. (required)
        :param str file_url: Optional; URL of a video file being used for conversion. Use this option for files larger than 2GB.
        :param int max_width: Optional; Maximum width of the output video, up to the original video width. Defaults to 250 pixels.
        :param int max_height: Optional; Maximum height of the output video, up to the original video width. Defaults to 250 pixels.
        :param bool preserve_aspect_ratio: Optional; If false, the original video's aspect ratio will not be preserved, allowing customization of the aspect ratio using maxWidth and maxHeight, potentially skewing the video. Default is true.
        :param int frame_rate: Optional; Specify the frame rate of the output video. Defaults to 24 frames per second.
        :param bool extend_processing_time: Optional; If true, will allow additional processing time for the video file conversion, using one API call per additional minute over the 5 minute default processing time, up to a maximum of 25 total minutes. This is generally necessary for files larger than 500 MB or longer than 30 minutes.
        :param datetime start_time: Optional; Specify the desired starting time of the GIF video in TimeSpan format.
        :param datetime time_span: Optional; Specify the desired length of the GIF video in TimeSpan format. Limit is 30 minutes.
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['input_file', 'file_url', 'max_width', 'max_height', 'preserve_aspect_ratio', 'frame_rate', 'extend_processing_time', 'start_time', 'time_span']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method video_convert_to_gif" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'input_file' is set
        if ('input_file' not in params or
                params['input_file'] is None):
            raise ValueError("Missing the required parameter `input_file` when calling `video_convert_to_gif`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'file_url' in params:
            header_params['fileUrl'] = params['file_url']  # noqa: E501
        if 'max_width' in params:
            header_params['maxWidth'] = params['max_width']  # noqa: E501
        if 'max_height' in params:
            header_params['maxHeight'] = params['max_height']  # noqa: E501
        if 'preserve_aspect_ratio' in params:
            header_params['preserveAspectRatio'] = params['preserve_aspect_ratio']  # noqa: E501
        if 'frame_rate' in params:
            header_params['frameRate'] = params['frame_rate']  # noqa: E501
        if 'extend_processing_time' in params:
            header_params['extendProcessingTime'] = params['extend_processing_time']  # noqa: E501
        if 'start_time' in params:
            header_params['startTime'] = params['start_time']  # noqa: E501
        if 'time_span' in params:
            header_params['timeSpan'] = params['time_span']  # noqa: E501

        form_params = []
        local_var_files = {}
        if 'input_file' in params:
            local_var_files['inputFile'] = params['input_file']  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/video/convert/to/gif', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def video_convert_to_mov(self, input_file, **kwargs):  # noqa: E501
        """Convert Video to MOV format.  # noqa: E501

        Automatically detect video file format and convert it to MOV format. Supports many input video formats, including AVI, ASF, FLV, MP4, MPEG/MPG, Matroska/WEBM, 3G2, OGV, MKV, M4V and MOV. Uses 1 API call per 10 MB of file size. Maximum output file size is 50GB.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.video_convert_to_mov(input_file, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param file input_file: Input file to perform the operation on. (required)
        :param str file_url: Optional; URL of a video file being used for conversion. Use this option for files larger than 2GB.
        :param int max_width: Optional; Maximum width of the output video, up to the original video width. Defaults to original video width.
        :param int max_height: Optional; Maximum height of the output video, up to the original video width. Defaults to original video height.
        :param bool preserve_aspect_ratio: Optional; If false, the original video's aspect ratio will not be preserved, allowing customization of the aspect ratio using maxWidth and maxHeight, potentially skewing the video. Default is true.
        :param int frame_rate: Optional; Specify the frame rate of the output video. Defaults to original video frame rate.
        :param int quality: Optional; Specify the quality of the output video, where 100 is lossless and 1 is the lowest possible quality with highest compression. Default is 50.
        :param bool extend_processing_time: Optional; If true, will allow additional processing time for the video file conversion, using one API call per additional minute over the 5 minute default processing time, up to a maximum of 25 total minutes. This is generally necessary for files larger than 500 MB or longer than 30 minutes.
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.video_convert_to_mov_with_http_info(input_file, **kwargs)  # noqa: E501
        else:
            (data) = self.video_convert_to_mov_with_http_info(input_file, **kwargs)  # noqa: E501
            return data

    def video_convert_to_mov_with_http_info(self, input_file, **kwargs):  # noqa: E501
        """Convert Video to MOV format.  # noqa: E501

        Automatically detect video file format and convert it to MOV format. Supports many input video formats, including AVI, ASF, FLV, MP4, MPEG/MPG, Matroska/WEBM, 3G2, OGV, MKV, M4V and MOV. Uses 1 API call per 10 MB of file size. Maximum output file size is 50GB.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.video_convert_to_mov_with_http_info(input_file, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param file input_file: Input file to perform the operation on. (required)
        :param str file_url: Optional; URL of a video file being used for conversion. Use this option for files larger than 2GB.
        :param int max_width: Optional; Maximum width of the output video, up to the original video width. Defaults to original video width.
        :param int max_height: Optional; Maximum height of the output video, up to the original video width. Defaults to original video height.
        :param bool preserve_aspect_ratio: Optional; If false, the original video's aspect ratio will not be preserved, allowing customization of the aspect ratio using maxWidth and maxHeight, potentially skewing the video. Default is true.
        :param int frame_rate: Optional; Specify the frame rate of the output video. Defaults to original video frame rate.
        :param int quality: Optional; Specify the quality of the output video, where 100 is lossless and 1 is the lowest possible quality with highest compression. Default is 50.
        :param bool extend_processing_time: Optional; If true, will allow additional processing time for the video file conversion, using one API call per additional minute over the 5 minute default processing time, up to a maximum of 25 total minutes. This is generally necessary for files larger than 500 MB or longer than 30 minutes.
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['input_file', 'file_url', 'max_width', 'max_height', 'preserve_aspect_ratio', 'frame_rate', 'quality', 'extend_processing_time']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method video_convert_to_mov" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'input_file' is set
        if ('input_file' not in params or
                params['input_file'] is None):
            raise ValueError("Missing the required parameter `input_file` when calling `video_convert_to_mov`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'file_url' in params:
            header_params['fileUrl'] = params['file_url']  # noqa: E501
        if 'max_width' in params:
            header_params['maxWidth'] = params['max_width']  # noqa: E501
        if 'max_height' in params:
            header_params['maxHeight'] = params['max_height']  # noqa: E501
        if 'preserve_aspect_ratio' in params:
            header_params['preserveAspectRatio'] = params['preserve_aspect_ratio']  # noqa: E501
        if 'frame_rate' in params:
            header_params['frameRate'] = params['frame_rate']  # noqa: E501
        if 'quality' in params:
            header_params['quality'] = params['quality']  # noqa: E501
        if 'extend_processing_time' in params:
            header_params['extendProcessingTime'] = params['extend_processing_time']  # noqa: E501

        form_params = []
        local_var_files = {}
        if 'input_file' in params:
            local_var_files['inputFile'] = params['input_file']  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/video/convert/to/mov', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def video_convert_to_mp4(self, input_file, **kwargs):  # noqa: E501
        """Convert Video to MP4 format.  # noqa: E501

        Automatically detect video file format and convert it to MP4 format. Supports many input video formats, including AVI, ASF, FLV, MP4, MPEG/MPG, Matroska/WEBM, 3G2, OGV, MKV, M4V and MOV. Uses 1 API call per 10 MB of file size. Maximum output file size is 50GB.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.video_convert_to_mp4(input_file, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param file input_file: Input file to perform the operation on. (required)
        :param str file_url: Optional; URL of a video file being used for conversion. Use this option for files larger than 2GB.
        :param int max_width: Optional; Maximum width of the output video, up to the original video width. Defaults to original video width.
        :param int max_height: Optional; Maximum height of the output video, up to the original video width. Defaults to original video height.
        :param bool preserve_aspect_ratio: Optional; If false, the original video's aspect ratio will not be preserved, allowing customization of the aspect ratio using maxWidth and maxHeight, potentially skewing the video. Default is true.
        :param int frame_rate: Optional; Specify the frame rate of the output video. Defaults to original video frame rate.
        :param int quality: Optional; Specify the quality of the output video, where 100 is lossless and 1 is the lowest possible quality with highest compression. Default is 50.
        :param bool extend_processing_time: Optional; If true, will allow additional processing time for the video file conversion, using one API call per additional minute over the 5 minute default processing time, up to a maximum of 25 total minutes. This is generally necessary for files larger than 500 MB or longer than 30 minutes.
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.video_convert_to_mp4_with_http_info(input_file, **kwargs)  # noqa: E501
        else:
            (data) = self.video_convert_to_mp4_with_http_info(input_file, **kwargs)  # noqa: E501
            return data

    def video_convert_to_mp4_with_http_info(self, input_file, **kwargs):  # noqa: E501
        """Convert Video to MP4 format.  # noqa: E501

        Automatically detect video file format and convert it to MP4 format. Supports many input video formats, including AVI, ASF, FLV, MP4, MPEG/MPG, Matroska/WEBM, 3G2, OGV, MKV, M4V and MOV. Uses 1 API call per 10 MB of file size. Maximum output file size is 50GB.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.video_convert_to_mp4_with_http_info(input_file, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param file input_file: Input file to perform the operation on. (required)
        :param str file_url: Optional; URL of a video file being used for conversion. Use this option for files larger than 2GB.
        :param int max_width: Optional; Maximum width of the output video, up to the original video width. Defaults to original video width.
        :param int max_height: Optional; Maximum height of the output video, up to the original video width. Defaults to original video height.
        :param bool preserve_aspect_ratio: Optional; If false, the original video's aspect ratio will not be preserved, allowing customization of the aspect ratio using maxWidth and maxHeight, potentially skewing the video. Default is true.
        :param int frame_rate: Optional; Specify the frame rate of the output video. Defaults to original video frame rate.
        :param int quality: Optional; Specify the quality of the output video, where 100 is lossless and 1 is the lowest possible quality with highest compression. Default is 50.
        :param bool extend_processing_time: Optional; If true, will allow additional processing time for the video file conversion, using one API call per additional minute over the 5 minute default processing time, up to a maximum of 25 total minutes. This is generally necessary for files larger than 500 MB or longer than 30 minutes.
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['input_file', 'file_url', 'max_width', 'max_height', 'preserve_aspect_ratio', 'frame_rate', 'quality', 'extend_processing_time']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method video_convert_to_mp4" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'input_file' is set
        if ('input_file' not in params or
                params['input_file'] is None):
            raise ValueError("Missing the required parameter `input_file` when calling `video_convert_to_mp4`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'file_url' in params:
            header_params['fileUrl'] = params['file_url']  # noqa: E501
        if 'max_width' in params:
            header_params['maxWidth'] = params['max_width']  # noqa: E501
        if 'max_height' in params:
            header_params['maxHeight'] = params['max_height']  # noqa: E501
        if 'preserve_aspect_ratio' in params:
            header_params['preserveAspectRatio'] = params['preserve_aspect_ratio']  # noqa: E501
        if 'frame_rate' in params:
            header_params['frameRate'] = params['frame_rate']  # noqa: E501
        if 'quality' in params:
            header_params['quality'] = params['quality']  # noqa: E501
        if 'extend_processing_time' in params:
            header_params['extendProcessingTime'] = params['extend_processing_time']  # noqa: E501

        form_params = []
        local_var_files = {}
        if 'input_file' in params:
            local_var_files['inputFile'] = params['input_file']  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/video/convert/to/mp4', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def video_convert_to_webm(self, input_file, **kwargs):  # noqa: E501
        """Convert Video to WEBM format.  # noqa: E501

        Automatically detect video file format and convert it to WEBM format. Supports many input video formats, including AVI, ASF, FLV, MP4, MPEG/MPG, Matroska/WEBM, 3G2, OGV, MKV, M4V and MOV. Uses 1 API call per 10 MB of file size. Maximum output file size is 50GB.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.video_convert_to_webm(input_file, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param file input_file: Input file to perform the operation on. (required)
        :param str file_url: Optional; URL of a video file being used for conversion. Use this option for files larger than 2GB.
        :param int max_width: Optional; Maximum width of the output video, up to the original video width. Defaults to original video width.
        :param int max_height: Optional; Maximum height of the output video, up to the original video width. Defaults to original video height.
        :param bool preserve_aspect_ratio: Optional; If false, the original video's aspect ratio will not be preserved, allowing customization of the aspect ratio using maxWidth and maxHeight, potentially skewing the video. Default is true.
        :param int frame_rate: Optional; Specify the frame rate of the output video. Defaults to original video frame rate.
        :param int quality: Optional; Specify the quality of the output video, where 100 is lossless and 1 is the lowest possible quality with highest compression. Default is 50.
        :param bool extend_processing_time: Optional; If true, will allow additional processing time for the video file conversion, using one API call per additional minute over the 5 minute default processing time, up to a maximum of 25 total minutes. This is generally necessary for files larger than 500 MB or longer than 30 minutes.
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.video_convert_to_webm_with_http_info(input_file, **kwargs)  # noqa: E501
        else:
            (data) = self.video_convert_to_webm_with_http_info(input_file, **kwargs)  # noqa: E501
            return data

    def video_convert_to_webm_with_http_info(self, input_file, **kwargs):  # noqa: E501
        """Convert Video to WEBM format.  # noqa: E501

        Automatically detect video file format and convert it to WEBM format. Supports many input video formats, including AVI, ASF, FLV, MP4, MPEG/MPG, Matroska/WEBM, 3G2, OGV, MKV, M4V and MOV. Uses 1 API call per 10 MB of file size. Maximum output file size is 50GB.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.video_convert_to_webm_with_http_info(input_file, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param file input_file: Input file to perform the operation on. (required)
        :param str file_url: Optional; URL of a video file being used for conversion. Use this option for files larger than 2GB.
        :param int max_width: Optional; Maximum width of the output video, up to the original video width. Defaults to original video width.
        :param int max_height: Optional; Maximum height of the output video, up to the original video width. Defaults to original video height.
        :param bool preserve_aspect_ratio: Optional; If false, the original video's aspect ratio will not be preserved, allowing customization of the aspect ratio using maxWidth and maxHeight, potentially skewing the video. Default is true.
        :param int frame_rate: Optional; Specify the frame rate of the output video. Defaults to original video frame rate.
        :param int quality: Optional; Specify the quality of the output video, where 100 is lossless and 1 is the lowest possible quality with highest compression. Default is 50.
        :param bool extend_processing_time: Optional; If true, will allow additional processing time for the video file conversion, using one API call per additional minute over the 5 minute default processing time, up to a maximum of 25 total minutes. This is generally necessary for files larger than 500 MB or longer than 30 minutes.
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['input_file', 'file_url', 'max_width', 'max_height', 'preserve_aspect_ratio', 'frame_rate', 'quality', 'extend_processing_time']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method video_convert_to_webm" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'input_file' is set
        if ('input_file' not in params or
                params['input_file'] is None):
            raise ValueError("Missing the required parameter `input_file` when calling `video_convert_to_webm`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'file_url' in params:
            header_params['fileUrl'] = params['file_url']  # noqa: E501
        if 'max_width' in params:
            header_params['maxWidth'] = params['max_width']  # noqa: E501
        if 'max_height' in params:
            header_params['maxHeight'] = params['max_height']  # noqa: E501
        if 'preserve_aspect_ratio' in params:
            header_params['preserveAspectRatio'] = params['preserve_aspect_ratio']  # noqa: E501
        if 'frame_rate' in params:
            header_params['frameRate'] = params['frame_rate']  # noqa: E501
        if 'quality' in params:
            header_params['quality'] = params['quality']  # noqa: E501
        if 'extend_processing_time' in params:
            header_params['extendProcessingTime'] = params['extend_processing_time']  # noqa: E501

        form_params = []
        local_var_files = {}
        if 'input_file' in params:
            local_var_files['inputFile'] = params['input_file']  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/video/convert/to/webm', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def video_get_info(self, input_file, **kwargs):  # noqa: E501
        """Get detailed information about a video or audio file  # noqa: E501

        Retrieve detailed information about a video or audio file, including format, dimensions, file size, bit rate, duration and start time. Compatible with many formats, including: AVI, ASF, FLV, GIF, MP4, MPEG/MPG, Matroska/WEBM, MOV, AIFF, ASF, CAF, MP3, MP2, MP1, Ogg, OMG/OMA, and WAV. Uses 1 API call per 10 MB of file size.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.video_get_info(input_file, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param file input_file: Input file to perform the operation on. (required)
        :param str file_url: Optional; URL of a video file being used for conversion. Use this option for files larger than 2GB.
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.video_get_info_with_http_info(input_file, **kwargs)  # noqa: E501
        else:
            (data) = self.video_get_info_with_http_info(input_file, **kwargs)  # noqa: E501
            return data

    def video_get_info_with_http_info(self, input_file, **kwargs):  # noqa: E501
        """Get detailed information about a video or audio file  # noqa: E501

        Retrieve detailed information about a video or audio file, including format, dimensions, file size, bit rate, duration and start time. Compatible with many formats, including: AVI, ASF, FLV, GIF, MP4, MPEG/MPG, Matroska/WEBM, MOV, AIFF, ASF, CAF, MP3, MP2, MP1, Ogg, OMG/OMA, and WAV. Uses 1 API call per 10 MB of file size.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.video_get_info_with_http_info(input_file, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param file input_file: Input file to perform the operation on. (required)
        :param str file_url: Optional; URL of a video file being used for conversion. Use this option for files larger than 2GB.
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['input_file', 'file_url']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method video_get_info" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'input_file' is set
        if ('input_file' not in params or
                params['input_file'] is None):
            raise ValueError("Missing the required parameter `input_file` when calling `video_get_info`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'file_url' in params:
            header_params['fileUrl'] = params['file_url']  # noqa: E501

        form_params = []
        local_var_files = {}
        if 'input_file' in params:
            local_var_files['inputFile'] = params['input_file']  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/video/convert/get-info', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    videoapi

    The video APIs help you convert, encode, and transcode videos.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class MediaInformation(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'successful': 'bool',
        'file_format': 'str',
        'file_format_full': 'str',
        'valid_file_formats': 'list[str]',
        'width': 'int',
        'height': 'int',
        'size': 'int',
        'bit_rate': 'int',
        'duration': 'float',
        'start_time': 'float'
    }

    attribute_map = {
        'successful': 'Successful',
        'file_format': 'FileFormat',
        'file_format_full': 'FileFormatFull',
        'valid_file_formats': 'ValidFileFormats',
        'width': 'Width',
        'height': 'Height',
        'size': 'Size',
        'bit_rate': 'BitRate',
        'duration': 'Duration',
        'start_time': 'StartTime'
    }

    def __init__(self, successful=None, file_format=None, file_format_full=None, valid_file_formats=None, width=None, height=None, size=None, bit_rate=None, duration=None, start_time=None):  # noqa: E501
        """MediaInformation - a model defined in Swagger"""  # noqa: E501

        self._successful = None
        self._file_format = None
        self._file_format_full = None
        self._valid_file_formats = None
        self._width = None
        self._height = None
        self._size = None
        self._bit_rate = None
        self._duration = None
        self._start_time = None
        self.discriminator = None

        if successful is not None:
            self.successful = successful
        if file_format is not None:
            self.file_format = file_format
        if file_format_full is not None:
            self.file_format_full = file_format_full
        if valid_file_formats is not None:
            self.valid_file_formats = valid_file_formats
        if width is not None:
            self.width = width
        if height is not None:
            self.height = height
        if size is not None:
            self.size = size
        if bit_rate is not None:
            self.bit_rate = bit_rate
        if duration is not None:
            self.duration = duration
        if start_time is not None:
            self.start_time = start_time

    @property
    def successful(self):
        """Gets the successful of this MediaInformation.  # noqa: E501

        True if the operation was successful, false otherwise  # noqa: E501

        :return: The successful of this MediaInformation.  # noqa: E501
        :rtype: bool
        """
        return self._successful

    @successful.setter
    def successful(self, successful):
        """Sets the successful of this MediaInformation.

        True if the operation was successful, false otherwise  # noqa: E501

        :param successful: The successful of this MediaInformation.  # noqa: E501
        :type: bool
        """

        self._successful = successful

    @property
    def file_format(self):
        """Gets the file_format of this MediaInformation.  # noqa: E501

        The file's short format name  # noqa: E501

        :return: The file_format of this MediaInformation.  # noqa: E501
        :rtype: str
        """
        return self._file_format

    @file_format.setter
    def file_format(self, file_format):
        """Sets the file_format of this MediaInformation.

        The file's short format name  # noqa: E501

        :param file_format: The file_format of this MediaInformation.  # noqa: E501
        :type: str
        """

        self._file_format = file_format

    @property
    def file_format_full(self):
        """Gets the file_format_full of this MediaInformation.  # noqa: E501

        The file's full format name  # noqa: E501

        :return: The file_format_full of this MediaInformation.  # noqa: E501
        :rtype: str
        """
        return self._file_format_full

    @file_format_full.setter
    def file_format_full(self, file_format_full):
        """Sets the file_format_full of this MediaInformation.

        The file's full format name  # noqa: E501

        :param file_format_full: The file_format_full of this MediaInformation.  # noqa: E501
        :type: str
        """

        self._file_format_full = file_format_full

    @property
    def valid_file_formats(self):
        """Gets the valid_file_formats of this MediaInformation.  # noqa: E501

        A list of the file's valid formats  # noqa: E501

        :return: The valid_file_formats of this MediaInformation.  # noqa: E501
        :rtype: list[str]
        """
        return self._valid_file_formats

    @valid_file_formats.setter
    def valid_file_formats(self, valid_file_formats):
        """Sets the valid_file_formats of this MediaInformation.

        A list of the file's valid formats  # noqa: E501

        :param valid_file_formats: The valid_file_formats of this MediaInformation.  # noqa: E501
        :type: list[str]
        """

        self._valid_file_formats = valid_file_formats

    @property
    def width(self):
        """Gets the width of this MediaInformation.  # noqa: E501

        The video's width, if file is a video  # noqa: E501

        :return: The width of this MediaInformation.  # noqa: E501
        :rtype: int
        """
        return self._width

    @width.setter
    def width(self, width):
        """Sets the width of this MediaInformation.

        The video's width, if file is a video  # noqa: E501

        :param width: The width of this MediaInformation.  # noqa: E501
        :type: int
        """

        self._width = width

    @property
    def height(self):
        """Gets the height of this MediaInformation.  # noqa: E501

        The video's height, if file is a video  # noqa: E501

        :return: The height of this MediaInformation.  # noqa: E501
        :rtype: int
        """
        return self._height

    @height.setter
    def height(self, height):
        """Sets the height of this MediaInformation.

        The video's height, if file is a video  # noqa: E501

        :param height: The height of this MediaInformation.  # noqa: E501
        :type: int
        """

        self._height = height

    @property
    def size(self):
        """Gets the size of this MediaInformation.  # noqa: E501

        The file's size in bytes  # noqa: E501

        :return: The size of this MediaInformation.  # noqa: E501
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this MediaInformation.

        The file's size in bytes  # noqa: E501

        :param size: The size of this MediaInformation.  # noqa: E501
        :type: int
        """

        self._size = size

    @property
    def bit_rate(self):
        """Gets the bit_rate of this MediaInformation.  # noqa: E501

        The file's bit rate  # noqa: E501

        :return: The bit_rate of this MediaInformation.  # noqa: E501
        :rtype: int
        """
        return self._bit_rate

    @bit_rate.setter
    def bit_rate(self, bit_rate):
        """Sets the bit_rate of this MediaInformation.

        The file's bit rate  # noqa: E501

        :param bit_rate: The bit_rate of this MediaInformation.  # noqa: E501
        :type: int
        """

        self._bit_rate = bit_rate

    @property
    def duration(self):
        """Gets the duration of this MediaInformation.  # noqa: E501

        The file's duration in seconds  # noqa: E501

        :return: The duration of this MediaInformation.  # noqa: E501
        :rtype: float
        """
        return self._duration

    @duration.setter
    def duration(self, duration):
        """Sets the duration of this MediaInformation.

        The file's duration in seconds  # noqa: E501

        :param duration: The duration of this MediaInformation.  # noqa: E501
        :type: float
        """

        self._duration = duration

    @property
    def start_time(self):
        """Gets the start_time of this MediaInformation.  # noqa: E501

        The file's media start time  # noqa: E501

        :return: The start_time of this MediaInformation.  # noqa: E501
        :rtype: float
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this MediaInformation.

        The file's media start time  # noqa: E501

        :param start_time: The start_time of this MediaInformation.  # noqa: E501
        :type: float
        """

        self._start_time = start_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(MediaInformation, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MediaInformation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa

"""
    videoapi

    The video APIs help you convert, encode, and transcode videos.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import apis into sdk package
from cloudmersive_video_api_client.api.video_api import VideoApi

# import ApiClient
from cloudmersive_video_api_client.api_client import ApiClient
from cloudmersive_video_api_client.configuration import Configuration
# import models into sdk package
from cloudmersive_video_api_client.models.media_information import MediaInformation



# coding: utf-8

"""
    videoapi

    The video APIs help you convert, encode, and transcode videos.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import cloudmersive_video_api_client
from cloudmersive_video_api_client.api.video_api import VideoApi  # noqa: E501
from cloudmersive_video_api_client.rest import ApiException


class TestVideoApi(unittest.TestCase):
    """VideoApi unit test stubs"""

    def setUp(self):
        self.api = cloudmersive_video_api_client.api.video_api.VideoApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_video_convert_to_gif(self):
        """Test case for video_convert_to_gif

        Convert Video to Animated GIF format.  # noqa: E501
        """
        pass

    def test_video_convert_to_mov(self):
        """Test case for video_convert_to_mov

        Convert Video to MOV format.  # noqa: E501
        """
        pass

    def test_video_convert_to_mp4(self):
        """Test case for video_convert_to_mp4

        Convert Video to MP4 format.  # noqa: E501
        """
        pass

    def test_video_convert_to_webm(self):
        """Test case for video_convert_to_webm

        Convert Video to WEBM format.  # noqa: E501
        """
        pass

    def test_video_get_info(self):
        """Test case for video_get_info

        Get detailed information about a video or audio file  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
